@@ -295,6 +295,12 @@ class CompileOptions {
         options_.get(), b);
   }
 
+  // If true, enable 16-bit types.  Default is false.
+  shaderc_spvc_status SetHLSLEnable16BitTypes(bool b) {
+    return shaderc_spvc_compile_options_set_hlsl_enable_16bit_types(
+        options_.get(), b);
+  }
+
   // If true, set non-writable storage images to be SRV, see spirv_hlsl.hpp in
   // SPIRV-Cross for more details.
   shaderc_spvc_status SetHLSLNonWritableUAVTextureAsSRV(bool b) {
